@@ -35,8 +35,7 @@ sub AUTOLOAD {
   }
 }
 
-my @methods = qw/insert insert_at update update_at update_all
-delete delete_at delete_all select select_at count/;
+my @methods = qw(insert update update_all delete delete_all select count);
 for my $method (@methods) {
   
   my $code =
@@ -47,8 +46,8 @@ for my $method (@methods) {
 
   
   my @attrs = qw/table type primary_key bind_type/;
-  my @insert_attrs = qw/created_at updated_at ctime mtime/;
-  my @update_attrs = qw/updated_at mtime/;
+  my @insert_attrs = qw/ctime mtime/;
+  my @update_attrs = qw/mtime/;
   my @select_attrs = qw/join/;
   if ($method eq 'insert') { push @attrs, @insert_attrs }
   elsif ($method eq 'update') { push @attrs, @update_attrs }
@@ -86,31 +85,6 @@ sub update_or_insert {
   else { croak "selected row must be one " . _subname }
 }
 
-sub execute {
-  my $self = shift;
-  
-  if ($ENV{DBIX_CUSTOM_DISABLE_MODEL_EXECUTE}) {
-      $self->dbi->execute(@_);
-  }
-  else {
-    _deprecate('0.24', "DBIx::Custom::Model execute method is DEPRECATED! " .
-      "use DBIx::Custom execute method. " .
-      "If you want to call DBIx::Custom execute method directory from model, " .
-      "set \$ENV{DBIX_CUSTOM_DISABLE_MODEL_EXECUTE} to 1 " .
-      "until DBIx::Custom::Model execute method is removed in the future." );
-    
-    return $self->dbi->execute(
-      shift,
-      shift,
-      table => $self->table,
-      bind_type => $self->bind_type,
-      primary_key => $self->primary_key,
-      type => $self->type,
-      @_
-    );    
-  }
-}
-
 sub DESTROY { }
 
 sub helper {
@@ -146,7 +120,7 @@ sub new {
   }
   
   # Cache
-  for my $attr (qw/dbi table created_at updated_at ctime mtime bind_type join primary_key/) {
+  for my $attr (qw/dbi table ctime mtime bind_type join primary_key/) {
     $self->$attr;
     $self->{$attr} = undef unless exists $self->{$attr};
   }
@@ -155,19 +129,6 @@ sub new {
   return $self;
 }
 
-# DEPRECATED!
-has 'filter';
-has 'name';
-has 'type';
-has 'created_at';
-has 'updated_at'; 
-
-# DEPRECATED!
-sub method {
-  _deprecate('0.24', "method method is DEPRECATED! use helper instead");
-  return shift->helper(@_);
-}
-
 1;
 
 =head1 NAME
@@ -327,7 +288,7 @@ you don't have to specify options if you set attribute in model.
 
 =head2 update_all
 
-  $model->update_all(param => \%param);
+  $model->update_all(\%param);
   
 Same as C<update_all> of L<DBIx::Custom> except that
 you don't have to specify options if you set attribute in model.
