@@ -40,27 +40,18 @@ sub fetch {
   }
   
   # Filter
-  if (($self->{filter} || $self->{default_filter}) && !$self->{filter_off}) {
-     my @columns = $self->{default_filter} ? keys %{$self->{_columns}}
-       : keys %{$self->{filter}};
+  if ($self->{filter}) {
+     my @columns = keys %{$self->{filter}};
      
      for my $column (@columns) {
-       my $filter = exists $self->{filter}->{$column} ? $self->{filter}->{$column}
-         : $self->{default_filter};
+       my $filter = $self->{filter}{$column};
        next unless $filter;
        $row[$_] = $filter->($row[$_])
          for @{$self->{_pos}{$column} || []};
      }
   }
-  if ($self->{end_filter} && !$self->{filter_off}) {
-     for my $column (keys %{$self->{end_filter}}) {
-       next unless $self->{end_filter}->{$column};
-       $row[$_] = $self->{end_filter}->{$column}->($row[$_])
-         for @{$self->{_pos}{$column} || []};
-     }
-  }
 
-  return \@row;
+  \@row;
 }
 
 sub fetch_hash {
@@ -92,24 +83,16 @@ sub fetch_hash {
     }
   }        
   # Filter
-  if (($self->{filter} || $self->{default_filter}) &&
-    !$self->{filter_off})
-  {
-     my @columns = $self->{default_filter} ? keys %{$self->{_columns}}
-       : keys %{$self->{filter}};
+  if ($self->{filter}) {
+     my @columns = keys %{$self->{filter}};
      
      for my $column (@columns) {
        next unless exists $row->{$column};
-       my $filter = exists $self->{filter}->{$column} ? $self->{filter}->{$column}
-         : $self->{default_filter};
+       my $filter = $self->{filter}->{$column};
        $row->{$column} = $filter->($row->{$column}) if $filter;
      }
   }
-  if ($self->{end_filter} && !$self->{filter_off}) {
-     exists $self->{_columns}{$_} && $self->{end_filter}->{$_} and
-         $row->{$_} = $self->{end_filter}->{$_}->($row->{$_})
-       for keys %{$self->{end_filter}};
-  }
+
   $row;
 }
 
@@ -384,111 +367,6 @@ sub _cache {
   $self->{_cache} = 1;
 }
 
-# DEPRECATED!
-sub column {
-  my $self = shift;
-  
-  _deprecate('0.25', "DBIx::Custom::Result::column method is DEPRECATED. "
-    . "use values method instead");
-  
-  return $self->values(@_);
-}
-
-# DEPRECATED!
-sub fetch_hash_first {
-  my $self = shift;
-  _deprecate('0.24', "DBIx::Custom::Result::fetch_hash_first is DEPRECATED! "
-    . "use fetch_hash_one instead");
-  return $self->fetch_hash_one(@_);
-}
-
-# DEPRECATED!
-sub fetch_first {
-  my $self = shift;
-  _deprecate('0.24', "DBIx::Custom::Result::fetch_first is DEPRECATED! "
-    . " use fetch_one instead");
-  return $self->fetch_one(@_);
-}
-
-# DEPRECATED!
-sub filter_off {
-  _deprecate('0.24', "filter_off method is DEPRECATED!");
-  my $self = shift;
-  $self->{filter_off} = 1;
-  return $self;
-}
-
-# DEPRECATED!
-sub filter_on {
-  _deprecated('0.24', "filter_on method is DEPRECATED!");
-  my $self = shift;
-  $self->{filter_off} = 0;
-  return $self;
-}
-
-# DEPRECATED!
-sub end_filter {
-  _deprecate('0.24', "end_filter method is DEPRECATED!");
-  my $self = shift;
-  if (@_) {
-    my $end_filter = {};
-    if (ref $_[0] eq 'HASH') { $end_filter = $_[0] }
-    else { 
-      $end_filter = _array_to_hash(
-          @_ > 1 ? [@_] : $_[0]
-      );
-    }
-    for my $column (keys %$end_filter) {
-      my $fname = $end_filter->{$column};
-      if (exists $end_filter->{$column}
-        && defined $fname
-        && ref $fname ne 'CODE') 
-      {
-        croak qq{Filter "$fname" is not registered" } . _subname
-          unless exists $self->dbi->filters->{$fname};
-        $end_filter->{$column} = $self->dbi->filters->{$fname};
-      }
-    }
-    $self->{end_filter} = {%{$self->end_filter}, %$end_filter};
-    return $self;
-  }
-  return $self->{end_filter} ||= {};
-}
-# DEPRECATED!
-sub remove_end_filter {
-  _deprecate('0.24', "remove_end_filter is DEPRECATED!");
-  my $self = shift;
-  $self->{end_filter} = {};
-  return $self;
-}
-# DEPRECATED!
-sub remove_filter {
-  _deprecate('0.24', "remove_filter is DEPRECATED!");
-  my $self = shift;
-  $self->{filter} = {};
-  return $self;
-}
-# DEPRECATED!
-sub default_filter {
-  _deprecate('0.24', "default_filter is DEPRECATED!");
-  my $self = shift;
-  if (@_) {
-    my $fname = $_[0];
-    if (@_ && !$fname) {
-      $self->{default_filter} = undef;
-    }
-    else {
-      croak qq{Filter "$fname" is not registered}
-        unless exists $self->dbi->filters->{$fname};
-      $self->{default_filter} = $self->dbi->filters->{$fname};
-    }
-    return $self;
-  }
-  return $self->{default_filter};
-}
-# DEPRECATED!
-has 'filter_check'; 
-
 1;
 
 =head1 NAME
